@@ -149,30 +149,37 @@ class DockerCommand(Command):
         """
         List containers.
 
-        Usage: ps
+        Usage: ps [options]
+
+        Options:
+            -q    Only display IDs
         """
         containers = self.docker.containers()
 
-        headers = ["ID", "Image", "Command", "Created", "Status", "IP Address", "Ports"]
+        if options['-q']:
+            for container in containers:
+                print container['Id'][:10]
+        else:
+            headers = ["ID", "Image", "Command", "Created", "Status", "IP Address", "Ports"]
 
-        for c in containers:
-            if c['Ports']:
-                mapping = c['Ports'][0]
-                c['Ports'] = '%s->%s' % (mapping['PublicPort'], mapping['PrivatePort'])
-            else:
-                c['Ports'] = ''
+            for c in containers:
+                if c['Ports']:
+                    mapping = c['Ports'][0]
+                    c['Ports'] = '%s->%s' % (mapping['PublicPort'], mapping['PrivatePort'])
+                else:
+                    c['Ports'] = ''
 
-        rows = [[
-            c['Id'][0:10],
-            c['Image'],
-            c['Command'][0:20],
-            prettydate(datetime.utcfromtimestamp(c['Created'])),
-            c['Status'],
-            c.get('ExternalIPAddress', ''),
-            c['Ports']
-        ] for c in containers]
+            rows = [[
+                c['Id'][0:10],
+                c['Image'],
+                c['Command'][0:20],
+                prettydate(datetime.utcfromtimestamp(c['Created'])),
+                c['Status'],
+                c.get('ExternalIPAddress', ''),
+                c['Ports']
+            ] for c in containers]
 
-        print self.formatter.table(headers, rows)
+            print self.formatter.table(headers, rows)
 
     def replace(self, options):
         """
@@ -387,7 +394,7 @@ class DockerCommand(Command):
         print "Go version:", docker_version["GoVersion"]
 
     def _attach_to_container(self, container_id, interactive, logs=False, stream=True, raw=False):
-        socket = self.docker.attach_websocket(
+        socket = self.docker.attach_socket(
             container_id,
             params={
                 'stdin': 1 if interactive else 0,
@@ -395,7 +402,8 @@ class DockerCommand(Command):
                 'stderr': 1,
                 'logs': 1 if logs else 0,
                 'stream': 1 if stream else 0
-            }
+            },
+            ws=True,
         )
 
         keep_running = lambda: self.docker.inspect_container(container_id)['State']['Running']
